@@ -22,13 +22,13 @@ from __future__ import absolute_import
 import sys
 from . import context
 
-VERSION = (3, 5, 0, 0)
+VERSION = (3, 6, 0, 0)
 __version__ = '.'.join(map(str, VERSION[0:4])) + "".join(VERSION[4:])
 __author__ = 'R Oudkerk / Python Software Foundation'
 __author_email__ = 'python-dev@python.org'
 __maintainer__ = 'Ask Solem'
 __contact__ = "ask@celeryproject.org"
-__homepage__ = "http://github.com/celery/billiard"
+__homepage__ = "https://github.com/celery/billiard"
 __docformat__ = "restructuredtext"
 
 # -eof meta-
